@@ -1,6 +1,6 @@
 package Reddit::Client;
 
-our $VERSION = '1.090'; 
+our $VERSION = '1.0901'; 
 $VERSION = eval $VERSION;
 
 use strict;
@@ -962,7 +962,7 @@ sub create_multi {
         	if ($model->{visibility} ne 'private' and
  	   	    $model->{visibility} ne 'public'  and
                     $model->{visibility} ne 'hidden') {
-                	croak "if provided, 'visibility' must be either 'public', 'private' or 'hidden'.";
+                	croak "if provided, 'visibility' must be either 'public', 'private', or 'hidden'.";
         	}
 	}
 
@@ -1195,16 +1195,52 @@ This function is an alias for C<submit_comment>, and is equivalent to
 
     submit_comment ( parent_id => $fullname, text => $text )
 
+=item create_multi
+
+    create_multi ( name => $multi_name, [ description => $description, ] [ visibility => $visibility, ]
+                 [ subreddits => [ subreddits ], ] [ icon_name => $icon_name, ] [ key_color => $hex_code, ]
+                 [ weighting_scheme => $weighting_scheme, ] )
+
+Create a multireddit. The only required argument is the name. A multi can also be created with C<edit_multi>, the only difference being that C<create_multi> will fail with a HTTP 409 error if a multi with that name already exists.
+
+Returns a hash of information about the newly created multireddit.
+
+I<name> The name of the multireddit. Maximum 50 characters. Only letters, numbers and underscores are allowed. Required.
+
+I<description> Description of the multi. This can contain markdown.
+
+I<visibility> One of 'private', 'public', or 'hidden'. Default 'private'.
+
+I<subreddits> or I<subs>: An array reference.
+
+The remaining arguments don't currently do anything. It seems like at least some of them are intended for future mobile updates.
+
+I<icon_name> If provided, must be one of the following values: 'art and design', 'ask', 'books', 'business', 'cars', 'comics', 'cute animals', 'diy', 'entertainment', 'food and drink', 'funny', 'games', 'grooming', 'health', 'life advice', 'military', 'models pinup', 'music', 'news', 'philosophy', 'pictures and gifs', 'science', 'shopping', 'sports', 'style', 'tech', 'travel', 'unusual stories', 'video', '', 'None'.
+
+I<weighting_scheme> If provided, must be either 'classic' or 'fresh'.
+
+I<key_color> A 6-character hex code. Defaults to CEE3F8.
+
 =item delete 
 
     delete ( $fullname )
 
 Delete a post or comment.
 
+=item delete_multi
+
+    delete_multi ( $multireddit_name )
+	
+Delete a multireddit.
+
+=item edit_multi
+
+Edit a multireddit. Will create a new multireddit if one with that name doesn't exist. The arguments are identical to C<create_multi>.
+
 =item edit_wiki
 
     edit_wiki ( subreddit => $subreddit, page => $page, content => $content,
-	            [ previous => $previous_version_number,] [ reason => $edit_reason, ] )
+              [ previous => $previous_version_number,] [ reason => $edit_reason, ] )
 	
 I<page> is the page being edited.
 
@@ -1217,7 +1253,7 @@ I<previous> is the ID of the intended previous version of the page; if provided,
 =item find_subreddits
 
     find_subreddits ( q => $query, [ sort => 'relevance' ,] 
-                      [ limit => DEFAULT_LIMIT ,] [ before => undef ,] [ after => undef ,] )
+                    [ limit => DEFAULT_LIMIT ,] [ before => undef ,] [ after => undef ,] )
 
 Returns a list of Subreddit objects matching the search string I<$query>. Optionally sort them by I<sort>, which can be "relevance" or "activity".
 
@@ -1267,6 +1303,14 @@ I<view> is a feed type constant-- i.e. VIEW_HOT, VIEW_NEW, etc.
 		
 fetch_links is an alias for get_links.
 
+=item get_multi
+
+    get_multi ( name => $multi_name, [ user => $username, ] [ expand => 0, ] )
+	
+Get a hash of information about a multireddit. I<$username> defaults to your username.
+
+If I<expand> is true, returns more detailed information about the subreddits in the multi. This can be quite a bit of information, comparable to the amount of information contained in a Subreddit object, however it's not I<exactly> the same, and if you try to create a Subreddit object out of it you'll fail.
+
 =item get_permalink
 
     get_permalink ( $comment_id, $post_id )
@@ -1441,7 +1485,7 @@ Vote on a post or comment. Direction must be 1, 0, or -1 (0 to clear votes).
 
 =head1 AUTHOR
 
-L<mailto:earth-tone@ubwg.net>
+L<mailto:earthtone.rc@gmail.com>
 
 =head1 LICENSE
 
